*** qrt-ssur2.do
*** v1.2
***
*** Creates SSUR-2 forecasts from real-time data. Outputs f_NNN s_NNN ur_NNN, where NNN is
***   the date of the first forecast for the UR (i.e., the unemployment rate is known through
***   month NNN-1). NNN is the Stata date code for months, where 192 = 1976m1.
***
clear all
set more off
set type double
set matsize 1000

global path = "$HOME/research/ssur"

tempfile ssur_data
insheet using $path/bpea/ssur_data_bpea.csv, comma clear
gen int mdate = tm(1951m1)+_n-1
order mdate
drop v1
unab foo: *
foreach var of local foo {
  qui destring `var', replace force
}
tsset mdate, m
rename e E
rename u U
drop ??r

keep if mdate>=tm(1951m1)
sum mdate
local maxdate = r(max)+1

cap erase fhist-ssur2.dta
!rm *.out

local i = 1
preserve
forvalues rdate = 106/`maxdate' {
  noi disp "$S_DATE $S_TIME " %tm `rdate'
  restore, preserve
  outsheet mdate E U s f hwi uic if mdate<=`rdate'-1 using foo.csv, comma replace nonames
  !echo ",E,U,S,F,HWI,UIC" > input.csv
  !cat foo.csv >> input.csv
  !rats qrt-ssur2.prg qrt-ssur2-`rdate'.out
  insheet using output.csv, comma clear
  gen int mdate=tm(1951m1)+_n-1
  drop v1
  order mdate
  keep mdate s f ur
  rename s s_`rdate'
  rename f f_`rdate'
  rename ur ur_`rdate'
  if `i'>1 {
    merge 1:1 mdate using fhist-ssur2.dta, nogen
  }
  compress
  save fhist-ssur2.dta, replace
  local i=`++i'
}

use fhist-ssur2.dta, replace
drop s* f*
reshape long ur_, i(mdate) j(fcdate)
rename ur_ ur_ssur2
order fcdate mdate
sort fcdate mdate
format %tm *date
drop if ur==.
compress
save qrt-ssur2.dta, replace

* clean up
!gzip -f9 fhist-ssur2.dta
erase foo.csv
erase input.csv
erase output.csv
!tar czf qrt-ssur2-logs.tgz qrt-ssur2-*.out
!rm qrt-ssur2-*.out

if "$S_CONSOLE"=="console" exit, STATA clear
